"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.App = void 0;
const chalk_1 = __importDefault(require("chalk"));
const root_scene_1 = require("./components/root-scene");
const package_json_1 = require("../package.json");
const summary_1 = require("./analystic/summary");
const logger_1 = require("./libs/logger");
const packages_manager_1 = require("./managers/packages-manager");
class App {
    logger;
    rootScene;
    constructor(logger) {
        this.logger = logger;
        this.logger.log('%s\t%s', chalk_1.default.yellow(`${package_json_1.name}⚡️`), chalk_1.default.gray(`v${package_json_1.version}`));
        this.logger.log('');
    }
    async exec() {
        const file = process.argv[2];
        if (!file)
            return this.showHelp();
        const decryptedPassword = process.argv[3];
        let summary;
        try {
            this.rootScene = new root_scene_1.RootScene({ path: file, password: decryptedPassword }, this.logger.clone('root-scene'));
            summary = new summary_1.Summary(this.rootScene.logger);
            await this.rootScene?.exec();
        }
        finally {
            await this.rootScene?.dispose();
            summary?.print();
        }
    }
    showHelp() {
        this.logger.setLevel(logger_1.LoggerLevel.ALL);
        this.logger.log('%s\t%s', chalk_1.default.gray('Usage:'), chalk_1.default.yellow('ezrun|r [file] [password]'));
        this.logger.log('');
        this.logger.log(chalk_1.default.gray('Arguments:'));
        this.logger.log('  %s    \t\t%s', 'file', chalk_1.default.gray('Path of the scene file to run (required)'));
        this.logger.log('  %s  \t\t%s', 'password', chalk_1.default.gray('Password to decrypt the scene'));
        this.logger.log('');
        this.logger.log(chalk_1.default.gray('Informations:'));
        this.logger.log('· %s\t%s', 'Github project', chalk_1.default.gray('https://github.com/doanthuanthanh88/ezrun '));
        this.logger.log('· %s   \t%s', 'Npm package', chalk_1.default.gray('https://www.npmjs.com/package/ezrun'));
        this.logger.log('· %s  \t%s', 'Docker Image', chalk_1.default.gray('https://hub.docker.com/repository/docker/doanthuanthanh88/ezrun`)'));
        this.logger.log('');
        this.logger.debug('External tags:');
        const externalModules = packages_manager_1.PackagesManager.Dependencies;
        Object.keys(externalModules).forEach(moduleName => {
            this.logger.info(`${moduleName}${chalk_1.default.gray.dim(externalModules[moduleName])}`);
        });
    }
}
exports.App = App;
//# sourceMappingURL=app.js.map