"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyElementShadowPrototype = exports.ElementShadow = void 0;
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const async_function_1 = require("./../libs/async-function");
const variable_1 = require("./../libs/variable");
const IGNORE_EVAL_ELEMENT_SHADOW_PROPS = [
    '$$evalExps',
    '$$ignoreVarsBeforeExec',
    'skip',
    'error',
    'vars',
    'loop',
    'loopKey',
    'loopValue',
    'if',
    'tag',
    'parent',
    'parentState',
    'result',
    'logger',
    'scene',
    'rootScene'
];
class ElementShadow {
    id;
    $$evalExps = [];
    $$ignoreEvalProps = [];
    title;
    skip;
    ignoreError;
    error;
    log;
    vars;
    async;
    loop;
    loopKey;
    loopValue;
    if;
    tag;
    parentState = {};
    parent;
    result;
    logger;
    scene;
    rootScene;
    getParentByClassName(...ClazzTypes) {
        let parent = this.parent;
        do {
            if (ClazzTypes.some(ClazzType => parent instanceof ClazzType)) {
                return parent;
            }
            parent = parent?.parent;
        } while (parent);
        return parent;
    }
    async setVarsAfterExec() {
        if (this.vars) {
            const keys = await this.scene.setVars(this.vars, this.result, this);
            if (!keys?.length)
                return;
            this.logger.trace('[vars] \t%j', keys.reduce((sum, e) => {
                sum[e] = this.scene.localVars[e];
                return sum;
            }, {}));
        }
    }
    async evalPropsBeforeExec() {
        await Promise.all(this.$$evalExps.map(async (key) => {
            this[key] = await this.scene.getVars(this[key], this);
        }));
    }
    $$getLoggerLevel() {
        return this.log || this.parent?.$$getLoggerLevel();
    }
    $$markElementNeedReplace() {
        const props = Object.keys(this);
        this.$$evalExps = props.filter(key => {
            return !IGNORE_EVAL_ELEMENT_SHADOW_PROPS.includes(key) &&
                !this.$$ignoreEvalProps?.includes(key) &&
                (0, variable_1.isGetEvalExp)(this[key]);
        });
    }
    $$extend(baseProps, ids) {
        if (!ids?.length)
            return;
        if (typeof ids === 'string')
            ids = [ids];
        ids.forEach(id => {
            let cached = this.rootScene.templatesManager.getFromCached(id);
            if (!cached) {
                this.logger.warn(`Could not found element with id "${id}"`);
                cached = {
                    skip: true
                };
            }
            (0, lodash_merge_1.default)(baseProps, (0, lodash_clonedeep_1.default)(cached));
        });
    }
    $$export(id, props) {
        if (!id)
            return;
        this.rootScene.templatesManager.pushToCached(id, (0, lodash_clonedeep_1.default)(props));
        this.logger.trace('->    \t%s', id);
    }
    async callFunctionScript(script, ctx = this, others = {}) {
        const rs = await (0, async_function_1.callFunctionScript)(script, ctx, {
            logger: this.logger,
            vars: this.scene.localVars,
            utils: this.rootScene.globalUtils,
            ...others
        });
        return rs;
    }
    dispose() { }
}
exports.ElementShadow = ElementShadow;
const ownerProperties = Object.getOwnPropertyNames(ElementShadow.prototype).filter(k => !['constructor', 'exec', 'dispose'].includes(k));
function copyElementShadowPrototype(elem) {
    if (elem.$$clone)
        return;
    if (!elem.$$ignoreEvalProps)
        elem.$$ignoreEvalProps = [];
    ownerProperties.forEach(k => {
        if (!elem[k])
            elem[k] = ElementShadow.prototype[k];
    });
}
exports.copyElementShadowPrototype = copyElementShadowPrototype;
//# sourceMappingURL=element-shadow.js.map