"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const file_temp_1 = require("../../libs/file-temp");
const format_1 = require("../../libs/format");
const testing_1 = require("../../testing");
const exec_sh_1 = require("./exec-sh");
let execSh;
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterAll(async () => {
    await execSh.dispose();
});
test('should create a new file', async () => {
    const path = `/tmp/${(0, format_1.formatFileName)('No Say Ben( Remix ) | Cover Bố Mẹ Gấu | VanhLeg')}.mp3`;
    try {
        execSh = await testing_1.Testing.newElement(exec_sh_1.ExecSh, {
            title: 'Test function',
            script: `touch "${path}"`
        });
        await execSh.exec();
        expect((0, fs_1.existsSync)(path)).toBe(true);
    }
    finally {
        (0, fs_1.existsSync)(path) && (0, fs_1.unlinkSync)(path);
    }
});
test('should be executed', async () => {
    const txt = 'hello world';
    execSh = await testing_1.Testing.newElement(exec_sh_1.ExecSh, {
        title: 'Test function',
        script: `echo "${txt}"`
    });
    const msg = await execSh.exec();
    expect(msg).toBe(txt);
});
test('should get expression value from global vars', async () => {
    testing_1.Testing.vars.txt = 'hello world';
    execSh = await testing_1.Testing.newElement(exec_sh_1.ExecSh, 'echo "${vars.txt}"');
    const msg = await execSh.exec();
    expect(msg).toBe(testing_1.Testing.vars.txt);
});
test('should run from external file', async () => {
    const txt = 'hello world';
    const tmpFile = new file_temp_1.FileTemp('.execSh');
    await tmpFile.create(`echo "${txt}"`);
    try {
        execSh = await testing_1.Testing.newElement(exec_sh_1.ExecSh, {
            title: 'Test function',
            path: tmpFile.file
        });
        const msg = await execSh.exec();
        expect(msg).toBe(txt);
    }
    finally {
        tmpFile.remove();
    }
});
//# sourceMappingURL=exec-sh.spec.js.map