"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_temp_1 = require("../../libs/file-temp");
const testing_1 = require("../../testing");
const yaml_1 = require("yaml");
const file_read_1 = require("./file-read");
let reader;
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterEach(async () => {
    await reader.dispose();
});
test('Read text file', async () => {
    const tmp = new file_temp_1.FileTemp();
    await tmp.create('Hello world');
    try {
        reader = await testing_1.Testing.newElement(file_read_1.FileRead, {
            path: tmp.file,
            vars: {
                msg: '${this.result}'
            }
        });
        await reader.exec();
        expect(testing_1.Testing.vars.msg).toBe('Hello world');
    }
    finally {
        tmp.remove();
    }
});
test('Read json file', async () => {
    const tmp = new file_temp_1.FileTemp();
    await tmp.create(JSON.stringify({ msg: 'Hello world' }));
    try {
        reader = await testing_1.Testing.newElement(file_read_1.FileRead, {
            path: tmp.file,
            format: 'json',
            vars: {
                msg: '${this.result.msg}'
            }
        });
        await reader.exec();
        expect(testing_1.Testing.vars.msg).toBe('Hello world');
    }
    finally {
        tmp.remove();
    }
});
test('Read yaml file', async () => {
    const tmp = new file_temp_1.FileTemp();
    await tmp.create((0, yaml_1.stringify)({ msg: 'Hello world' }));
    try {
        reader = await testing_1.Testing.newElement(file_read_1.FileRead, {
            path: tmp.file,
            format: 'yaml',
            vars: 'data'
        });
        await reader.exec();
        expect(testing_1.Testing.vars.data.msg).toBe('Hello world');
    }
    finally {
        tmp.remove();
    }
});
//# sourceMappingURL=file-read.spec.js.map