"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const aes_1 = require("../../libs/encrypt/aes");
const file_temp_1 = require("../../libs/file-temp");
const testing_1 = require("../../testing");
const file_store_1 = require("./file-store");
let storage;
let tmp;
beforeEach(async () => {
    await testing_1.Testing.reset();
    tmp = new file_temp_1.FileTemp();
});
afterEach(async () => {
    await storage.dispose();
    tmp.remove();
});
test('Load with init data', async () => {
    const initData = ['init data'];
    storage = await testing_1.Testing.newElement(file_store_1.FileStore, {
        path: tmp.file,
        initData
    });
    const rs = await storage.exec();
    expect(rs).toBe(initData);
});
test('Add new data & save to file', async () => {
    storage = await testing_1.Testing.newElement(file_store_1.FileStore, {
        path: tmp.file,
        initData: []
    });
    const initData = await storage.exec();
    expect(initData).toStrictEqual([]);
    storage.data.push('new item');
    storage.save();
    const newData = storage.load();
    expect(newData).toStrictEqual(['new item']);
});
test('Encrypt data file with a password', async () => {
    storage = await testing_1.Testing.newElement(file_store_1.FileStore, {
        path: tmp.file,
        password: 'pwd',
        initData: ['name 1']
    });
    const initData = await storage.exec();
    expect(initData).toStrictEqual(['name 1']);
    const cnt = (0, fs_1.readFileSync)(tmp.file).toString();
    const decryptData = JSON.parse(new aes_1.AES('pwd').decrypt(cnt));
    expect(decryptData).toStrictEqual(['name 1']);
});
//# sourceMappingURL=file-store.spec.js.map