"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileWrite = void 0;
const fs_1 = require("fs");
const element_shadow_1 = require("../element-shadow");
const json_formater_1 = require("./write/json.formater");
const yaml_formater_1 = require("./write/yaml.formater");
class FileWrite extends element_shadow_1.ElementShadow {
    path = '';
    content;
    format;
    pretty;
    constructor(props) {
        super();
        Object.assign(this, props);
    }
    async exec() {
        if (!this.path)
            throw new Error('"path" is required');
        return await new Promise((resolve, reject) => {
            this.path = this.scene.getPath(this.path);
            this.logger.debug(`Write ${this.format || ''}/${this.pretty ? '(pretty)' : ''} file to "${this.path}"`).trace('%s', this.content);
            const formater = this.getFormater();
            if (formater) {
                this.content = formater.format(this.content);
            }
            (0, fs_1.writeFile)(this.path, this.content, (err) => err ? reject(err) : resolve(this.path));
        });
    }
    getFormater() {
        switch (this.format) {
            case 'json':
                return new json_formater_1.JSONFormater(this.pretty);
            case 'yaml':
                return new yaml_formater_1.YAMLFormater();
            default:
                return null;
        }
    }
}
exports.FileWrite = FileWrite;
//# sourceMappingURL=file-write.js.map