"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const group_1 = require("./group");
let group;
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterEach(async () => {
    await group.dispose();
});
test('if - condition', async () => {
    group = await testing_1.Testing.newElement(group_1.Group, [
        {
            echo: {
                loop: '${[1,2,3]}',
                if: '${this.loopValue %2 === 0}',
                content: '${this.loopValue}'
            }
        }
    ]);
    const [echo] = await group.exec();
    expect(echo.result).toBe(2);
});
test('loop', async () => {
    group = await testing_1.Testing.newElement(group_1.Group, [
        {
            echo: {
                loop: '${[1,2,3]}',
                content: '${this.loopValue}'
            }
        }
    ]);
    const echo = await group.exec();
    expect(echo).toHaveLength(3);
});
test('pass a config into item in group', async () => {
    group = await testing_1.Testing.newElement(group_1.Group, [
        {
            "exec'js": {
                script: 'return "OK"',
                vars: 'result'
            }
        }
    ]);
    await group.exec();
    expect(group.result).toHaveLength(1);
    expect(testing_1.Testing.vars.result).toBe('OK');
});
test('pass full group information', async () => {
    group = await testing_1.Testing.newElement(group_1.Group, {
        title: 'Test group',
        runs: [
            {
                "exec'js": {
                    script: 'return "OK"',
                    vars: 'result'
                }
            }
        ]
    });
    await group.exec();
    expect(group.result).toHaveLength(1);
    expect(testing_1.Testing.vars.result).toBe('OK');
});
test('run with false condition', async () => {
    group = await testing_1.Testing.newElement(group_1.Group, {
        title: 'Test group',
        runs: [
            {
                "exec'js": {
                    if: '${false}',
                    script: 'return "OK"',
                    vars: 'result'
                }
            }
        ]
    });
    await group.exec();
    expect(group.result).toHaveLength(0);
    expect(testing_1.Testing.vars.result).toBeUndefined();
});
//# sourceMappingURL=group.spec.js.map