"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Sub = void 0;
const http_1 = require("http");
const lodash_merge_1 = __importDefault(require("lodash.merge"));
const querystring_1 = require("querystring");
const job_1 = require("../../../components/.job/job");
class Sub extends job_1.Job {
    address = '0.0.0.0:8811';
    secure;
    basicAuthorizationToken;
    server;
    constructor({ address, secure, ...props }) {
        super(props);
        Object.assign(this, { address, secure });
        this.$$ignoreEvalProps.push('server', 'basicAuthorizationToken');
    }
    async execJob() {
        if (this.secure?.basic) {
            this.basicAuthorizationToken = `Basic ${this.rootScene.globalUtils.base64.encrypt(`${this.secure?.basic.username}:${this.secure?.basic.password}`)}`;
        }
        await new Promise((resolve, reject) => {
            const [host, port] = this.address.trim().split(':');
            this.server = (0, http_1.createServer)(async (req, res) => await this.handleRequest(req, res))
                .on('error', reject)
                .on('close', async () => {
                await super.stop();
                resolve(undefined);
            })
                .listen(+port, host, () => {
                this.logger.debug('http/jobs listened at %s', this.address);
            });
        });
    }
    async handleRequest(req, res) {
        this.logger.debug('%s %s \t%s', '⥃', req.method, req.url);
        try {
            const [path, qstr] = req.url?.split('?') || [];
            const info = {
                path,
                method: req.method,
                headers: req.headers,
                query: (0, querystring_1.parse)(qstr)
            };
            if (this.basicAuthorizationToken) {
                const authorization = req.headers.authorization || info.query.authorization;
                if (this.basicAuthorizationToken !== authorization) {
                    res.statusMessage = this.basicAuthorizationToken ? 'secured' : 'unsecured';
                    res.statusCode = 401;
                    res.end();
                    return;
                }
            }
            const data = { ...info.query };
            const requestBody = await this.getRequestBody(req);
            if (requestBody) {
                (0, lodash_merge_1.default)(data, requestBody);
            }
            await this.addJobData({
                jobData: data,
                jobInfo: info
            });
        }
        finally {
            res.statusMessage = this.basicAuthorizationToken ? 'secured' : 'unsecured';
            res.statusCode = 201;
            res.end();
        }
    }
    async getRequestBody(req) {
        return await new Promise((resolve, reject) => {
            const chunks = [];
            req.on('data', (chunk) => chunks.push(chunk));
            req.on('error', reject);
            req.on('end', () => {
                const data = Buffer.concat(chunks).toString();
                resolve(data ? JSON.parse(data) : data);
            });
        });
    }
    async stop() {
        if (!this.server?.listening)
            return;
        this.server?.close();
    }
    async dispose() {
        await this.stop();
    }
}
exports.Sub = Sub;
//# sourceMappingURL=sub.js.map