"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TagRegister = void 0;
const element_shadow_1 = require("../element-shadow");
class TagRegister extends element_shadow_1.ElementShadow {
    tags;
    constructor(tags) {
        super();
        Object.assign(this, { tags });
    }
    async exec() {
        const tagNames = this.tags && Object.keys(this.tags);
        if (!tagNames?.length)
            return;
        await Promise.all(Object.keys(this.tags || {})
            .map(async (key) => {
            const pathOrContent = this.tags?.[key] || '';
            if (pathOrContent.split('\n').length === 1) {
                this.scene.logger.trace('Loaded tags \t[%s] %s', key, pathOrContent);
                this.rootScene.tagsManager.register(key, pathOrContent);
            }
            else {
                try {
                    const tag = this.tags?.[key];
                    const obj = await this.callFunctionScript(`return ${tag}`);
                    obj.tag = key;
                    this.scene.logger.trace('Register tag \t[%s]', obj.tag);
                    this.rootScene.tagsManager.setTag(key, { default: obj });
                }
                catch (err) {
                    this.logger.error(`Register a custom tag "${key}" error`);
                    throw err;
                }
            }
        }));
    }
}
exports.TagRegister = TagRegister;
//# sourceMappingURL=tag-register.js.map