"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("../../testing");
const vars_1 = require("./vars");
let vars;
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterEach(async () => {
    await vars?.dispose();
});
test('should set to local vars which is used in the scene', async () => {
    try {
        vars = await testing_1.Testing.newElement(vars_1.Vars, {
            string: 'foo',
            number: 1,
            boolean: true,
            object: {
                string: 'foo',
                number: 1,
                boolean: true
            },
            array1: [1, '2', true],
            array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true
                }]
        });
        expect(testing_1.Testing.vars.String).toBeUndefined();
        expect(testing_1.Testing.vars.Number).toBeUndefined();
        expect(testing_1.Testing.vars.Boolean).toBeUndefined();
        expect(testing_1.Testing.vars.Object).toBeUndefined();
        expect(testing_1.Testing.vars.Array1).toBeUndefined();
        expect(testing_1.Testing.vars.Array2).toBeUndefined();
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
        await vars.exec();
        expect(testing_1.Testing.vars.string).toBe('foo');
        expect(testing_1.Testing.vars.number).toBe(1);
        expect(testing_1.Testing.vars.boolean).toBe(true);
        expect(testing_1.Testing.vars.object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true
        });
        expect(testing_1.Testing.vars.array1).toStrictEqual([1, '2', true]);
        expect(testing_1.Testing.vars.array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true
            }]);
        expect(testing_1.Testing.vars.String).toBeUndefined();
        expect(testing_1.Testing.vars.Number).toBeUndefined();
        expect(testing_1.Testing.vars.Boolean).toBeUndefined();
        expect(testing_1.Testing.vars.Object).toBeUndefined();
        expect(testing_1.Testing.vars.Array1).toBeUndefined();
        expect(testing_1.Testing.vars.Array2).toBeUndefined();
    }
    finally {
        await vars.dispose();
    }
});
test('should set to global vars', async () => {
    try {
        vars = await testing_1.Testing.newElement(vars_1.Vars, {
            String: 'foo',
            Number: 1,
            Boolean: true,
            Object: {
                string: 'foo',
                number: 1,
                boolean: true
            },
            Array1: [1, '2', true],
            Array2: [{
                    string: 'foo',
                    number: 1,
                    boolean: true
                }]
        });
        expect(testing_1.Testing.vars.String).toBeUndefined();
        expect(testing_1.Testing.vars.Number).toBeUndefined();
        expect(testing_1.Testing.vars.Boolean).toBeUndefined();
        expect(testing_1.Testing.vars.Object).toBeUndefined();
        expect(testing_1.Testing.vars.Array1).toBeUndefined();
        expect(testing_1.Testing.vars.Array2).toBeUndefined();
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
        await vars.exec();
        expect(testing_1.Testing.vars.String).toBe('foo');
        expect(testing_1.Testing.vars.Number).toBe(1);
        expect(testing_1.Testing.vars.Boolean).toBe(true);
        expect(testing_1.Testing.vars.Object).toStrictEqual({
            string: 'foo',
            number: 1,
            boolean: true
        });
        expect(testing_1.Testing.vars.Array1).toStrictEqual([1, '2', true]);
        expect(testing_1.Testing.vars.Array2).toStrictEqual([{
                string: 'foo',
                number: 1,
                boolean: true
            }]);
        expect(testing_1.Testing.vars.string).toBeUndefined();
        expect(testing_1.Testing.vars.number).toBeUndefined();
        expect(testing_1.Testing.vars.boolean).toBeUndefined();
        expect(testing_1.Testing.vars.object).toBeUndefined();
        expect(testing_1.Testing.vars.array1).toBeUndefined();
        expect(testing_1.Testing.vars.array2).toBeUndefined();
    }
    finally {
        await vars.dispose();
    }
});
test('should eval value into vars', async () => {
    vars = await testing_1.Testing.newElement(vars_1.Vars, {
        name: 'scene name',
        Name: 'global name'
    });
    await vars.exec();
    const test = await testing_1.Testing.newElement(vars_1.Vars, {
        Hello: 'Hello ${vars.Name}',
        hello: 'hello ${vars.name}'
    });
    await test.exec();
    await test.dispose();
    expect(testing_1.Testing.vars.hello).toBe('hello scene name');
    expect(testing_1.Testing.vars.Hello).toBe('Hello global name');
});
//# sourceMappingURL=vars.spec.js.map