"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.View = void 0;
const chalk_1 = __importDefault(require("chalk"));
const logger_1 = require("../../libs/logger");
const util_1 = require("util");
const element_shadow_1 = require("../element-shadow");
class View extends element_shadow_1.ElementShadow {
    data;
    constructor(props) {
        super();
        if (typeof props !== 'object') {
            props = {
                data: props
            };
        }
        Object.assign(this, props);
    }
    async exec() {
        if (this.logger.is(logger_1.LoggerLevel.INFO) && this.data) {
            this.print();
        }
        return this.data;
    }
    chalkByType(o, str) {
        const type = typeof o;
        if (type === 'string')
            return chalk_1.default.yellow(str);
        if (type === 'boolean')
            return chalk_1.default.red(str);
        if (type === 'number')
            return chalk_1.default.green(str);
        if (Array.isArray(o))
            return chalk_1.default.blue(str);
        if (type === 'object')
            return chalk_1.default.cyan(str);
        return chalk_1.default.white.dim(str);
    }
    prettyFormat(obj) {
        if (!obj || typeof obj !== 'object')
            return (0, util_1.format)(obj);
        if (Array.isArray(obj)) {
            obj.forEach((o, i) => {
                const key = this.chalkByType(o, '[%d]');
                if (typeof o === 'object') {
                    this.logger.log(`${key}: `, i);
                    this.logger.addIndent();
                    try {
                        this.prettyFormat(o);
                    }
                    finally {
                        this.logger.removeIndent();
                    }
                }
                else {
                    this.logger.log(`${key}: %j`, i, o);
                }
            });
        }
        else {
            for (const k in obj) {
                const o = obj[k];
                const key = this.chalkByType(o, '%s');
                if (typeof o === 'object') {
                    this.logger.log(`${key}: `, k);
                    this.logger.addIndent();
                    try {
                        this.prettyFormat(o);
                    }
                    finally {
                        this.logger.removeIndent();
                    }
                }
                else {
                    this.logger.log(`${key}: %j`, k, o);
                }
            }
        }
    }
    print() {
        this.logger.addIndent();
        try {
            this.format(this.data);
        }
        finally {
            this.logger.removeIndent();
        }
    }
    format(data) {
        this.prettyFormat(data);
    }
}
exports.View = View;
//# sourceMappingURL=view.js.map