"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JobsManager = void 0;
class JobsManager {
    logger;
    concurrent = 1;
    startProms;
    jobs = new Array();
    queueJobs = new Array();
    runningJobs = new Set();
    jobHandler;
    storage;
    error;
    constructor(logger, opts) {
        this.logger = logger;
        Object.assign(this, opts);
    }
    async add(job) {
        this.jobs.push(job);
        await this.storage?.save(this.jobs);
        this.queueJobs.push(job);
        this.pullJobToRun();
    }
    pullJobToRun() {
        if (!this.startProms)
            return;
        if (!this.concurrent) {
            if (!this.runningJobs.size) {
                clearTimeout(this.startProms.tm);
                this.error ? this.startProms.reject(this.error) : this.startProms.resolve();
            }
            return;
        }
        if (this.queueJobs.length && this.runningJobs.size < this.concurrent) {
            const job = this.queueJobs.shift();
            if (job) {
                this.logger.debug('Pulled a job').trace('%o', job);
                setImmediate(async (job) => {
                    try {
                        if (this.jobHandler?.onJobRun)
                            await this.jobHandler.onJobRun(job);
                        await job.jobExecute();
                        this.logger.debug('Job successed      ').trace('%o', job);
                        if (this.jobHandler?.onJobSuccess)
                            await this.jobHandler.onJobSuccess(job);
                        this.jobs.splice(this.jobs.indexOf(job), 1);
                        await this.storage?.save(this.jobs);
                    }
                    catch (err1) {
                        this.logger.debug('Job failed         \t%s', err1?.message).trace('%o', job);
                        this.queueJobs.splice(0, 0, job);
                        try {
                            if (this.jobHandler?.onJobFailure) {
                                await this.jobHandler.onJobFailure(err1, job);
                            }
                            else {
                                this.logger.debug('Jobs manager stoped');
                                this.concurrent = 0;
                            }
                        }
                        catch (err2) {
                            this.logger.debug('Jobs manager stoped\t%s', err2?.message).trace('%o', job);
                            this.logger.trace('%o', job);
                            this.concurrent = 0;
                            this.error = err2;
                        }
                    }
                    finally {
                        this.runningJobs.delete(job);
                        if (this.jobHandler?.onJobDone)
                            await this.jobHandler.onJobDone(job);
                    }
                    this.pullJobToRun();
                }, job);
                this.runningJobs.add(job);
            }
        }
    }
    async start() {
        if (this.jobHandler?.onJobInit) {
            const jobsData = await this.storage?.load([]);
            const jobs = await this.jobHandler?.onJobInit(jobsData);
            if (Array.isArray(jobs)) {
                for (const job of jobs) {
                    await this.add(job);
                }
            }
            else if (jobs) {
                await this.add(jobs);
            }
        }
        return await new Promise((resolve, reject) => {
            this.startProms = { resolve, reject, tm: setInterval(() => { }, 60000) };
            for (let i = 0; i < this.concurrent; i++) {
                this.pullJobToRun();
            }
        });
    }
    stop() {
        this.concurrent = 0;
        this.pullJobToRun();
    }
}
exports.JobsManager = JobsManager;
//# sourceMappingURL=jobs-manager.js.map