"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const testing_1 = require("./../testing");
const packages_manager_1 = require("./packages-manager");
let packageManager;
beforeEach(async () => {
    await testing_1.Testing.reset();
    jest.resetModules();
});
beforeAll(() => {
    packageManager = new packages_manager_1.PackagesManager(testing_1.Testing.rootScene);
});
afterAll(async () => {
    await packageManager.clean();
});
test('Install a new modules', async () => {
    const moduleNames = ['lodash.merge'];
    try {
        await packageManager.install(...moduleNames);
        const rs = packageManager.isInstalled(...moduleNames);
        expect(rs[0]).toBeTruthy();
        const dependencies = packages_manager_1.PackagesManager.Dependencies;
        expect(dependencies[moduleNames[0]]).toBeDefined();
    }
    finally {
        await packageManager.uninstall(...moduleNames);
    }
});
test('Uninstall a new modules', async () => {
    const moduleNames = ['lodash.clone', 'lodash.clonedeep'];
    try {
        await packageManager.install(...moduleNames);
        await packageManager.uninstall(moduleNames[0]);
        const rs = packageManager.isInstalled(...moduleNames);
        expect(rs[0]).toBeUndefined();
        expect(rs[1]).toBeTruthy();
        const dependencies = packages_manager_1.PackagesManager.Dependencies;
        expect(dependencies[moduleNames[0]]).toBeUndefined();
        expect(dependencies[moduleNames[1]]).toBeDefined();
    }
    finally {
        await packageManager.uninstall(...moduleNames);
    }
});
//# sourceMappingURL=packages-manager.spec.js.map