"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const file_temp_1 = require("./../libs/file-temp");
const testing_1 = require("./../testing");
const packages_manager_1 = require("./packages-manager");
beforeEach(async () => {
    await testing_1.Testing.reset();
});
afterEach(async () => {
});
test('Auto install external tags', async () => {
    const tagsManager = testing_1.Testing.rootScene.tagsManager;
    const packagesManager = new packages_manager_1.PackagesManager(testing_1.Testing.rootScene);
    try {
        const newClass = await tagsManager.loadElementClass('lodash', testing_1.Testing.rootScene);
        expect(newClass).toBeDefined();
    }
    catch {
        const [isInstalled] = packagesManager.isInstalled('lodash');
        expect(isInstalled).toBeTruthy();
    }
    finally {
        await packagesManager.uninstall('lodash');
    }
});
test('load a new tag from a class in a external file', async () => {
    const tmpFile = new file_temp_1.FileTemp('.js');
    try {
        await tmpFile.create(`
    module.exports = class {
      constructor(props) {
        this.props = props
      }
      exec() {
        return this.props
      }
      dispose() { }
    }`);
        const data = { say: 'hello test' };
        testing_1.Testing.rootScene.tagsManager.register('test1', tmpFile.file);
        const TestClass = await testing_1.Testing.rootScene.tagsManager.loadElementClass('test1', testing_1.Testing.rootScene);
        const test = await testing_1.Testing.newElement(TestClass, data);
        const rs = await test.exec();
        expect(rs).toEqual(data);
    }
    finally {
        tmpFile.remove();
    }
});
test('load a new tag from a object in a external file', async () => {
    const tmpFile = new file_temp_1.FileTemp('.js');
    try {
        await tmpFile.create(`
    module.exports = {
      constructor(props) {
        this.props = props
      },
      exec() {
        return this.props
      }
    }`);
        const data = { say: 'hello test' };
        testing_1.Testing.rootScene.tagsManager.register('test1', tmpFile.file);
        const TestClass = await testing_1.Testing.rootScene.tagsManager.loadElementClass('test1', testing_1.Testing.rootScene);
        const test = await testing_1.Testing.newElement(TestClass, data);
        const rs = await test.exec();
        expect(rs).toEqual(data);
    }
    finally {
        tmpFile.remove();
    }
});
//# sourceMappingURL=tags-manager.spec.js.map